
# Slot: all_of


holds if all of the expressions hold

URI: [linkml:type_expression_all_of](https://w3id.org/linkml/type_expression_all_of)


## Domain and Range

type_expression &#8594;  <sub>0..\*</sub> anonymous_type_expression

## Parents

 *  is_a: all_of

## Children


## Used by

 * anonymous_type_expression
 * type_definition
 * type_expression

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:and |

